summaryrefslogtreecommitdiffstats
path: root/usr/local/www/firewall_nat_1to1_edit.php
diff options
context:
space:
mode:
authorBill Marquette <billm@pfsense.org>2005-07-13 03:09:18 +0000
committerBill Marquette <billm@pfsense.org>2005-07-13 03:09:18 +0000
commit1425e067d6db9b41eafe67070742e3b466178053 (patch)
treec6996ad986ab75ecba8c3f1eb815134202bba875 /usr/local/www/firewall_nat_1to1_edit.php
parentaca8110ae9f52c81bc88e762fbaf9cb8f2d8d2ca (diff)
downloadpfsense-1425e067d6db9b41eafe67070742e3b466178053.zip
pfsense-1425e067d6db9b41eafe67070742e3b466178053.tar.gz
Merge in virtual IP code
This changeset does the following: merges proxy arp and carp setup menus removes proxy arp menu from left side upgrades config file from 1.7 to 1.8 moves existing carp virtual IP and proxy arp config to new <virtualip> tag removes server NAT (why duplicate work?)
Diffstat (limited to 'usr/local/www/firewall_nat_1to1_edit.php')
-rwxr-xr-xusr/local/www/firewall_nat_1to1_edit.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/usr/local/www/firewall_nat_1to1_edit.php b/usr/local/www/firewall_nat_1to1_edit.php
index 26fed2a..66f0ccd 100755
--- a/usr/local/www/firewall_nat_1to1_edit.php
+++ b/usr/local/www/firewall_nat_1to1_edit.php
@@ -96,12 +96,12 @@ if ($_POST) {
}
}
- /* check for overlaps with server NAT */
- if (is_array($config['nat']['servernat'])) {
- foreach ($config['nat']['servernat'] as $natent) {
+ /* check for overlaps with Virtual IPs */
+ if (is_array($config['virtualip']['vip'])) {
+ foreach ($config['virtualip']['vip'] as $vipent) {
if (check_subnets_overlap($_POST['external'], $_POST['subnet'],
- $natent['ipaddr'], 32)) {
- $input_errors[] = "A server NAT entry overlaps with the specified external subnet.";
+ $vipent['subnet'], 32)) {
+ $input_errors[] = "Virtual IP entry overlaps with the specified external subnet.";
break;
}
}
OpenPOWER on IntegriCloud